Changes
=======

Unreleased
----------

Version 0.6.2
-------------

Released 2022-08-11

- Update dependencies.
    - Bump cryptography to >=36,<38. `#43 <https://github.com/dajiaji/pyseto/pull/43>`__
- Update dev dependencies.
    - Bump pre-commit/flake8 to 5.0.4. `#51 <https://github.com/dajiaji/mkkey/pull/51>`__
    - Bump mypy to 0.971. `#49 <https://github.com/dajiaji/mkkey/pull/49>`__
    - Bump pre-commit/black to 22.6.0. `#48 <https://github.com/dajiaji/mkkey/pull/48>`__
    - Bump tox to 3.25.1. `#58 <https://github.com/dajiaji/mkkey/pull/58>`__
    - Bump pre-commit/pre-commit-hooks to 4.3.0. `#47 <https://github.com/dajiaji/mkkey/pull/47>`__
    - Bump pytest to ^7.0. `#37 <https://github.com/dajiaji/mkkey/pull/37>`__
    - Bump pre-commit/blacken-docs to 1.12.0. `#36 <https://github.com/dajiaji/mkkey/pull/36>`__

Version 0.6.1
-------------

Released 2021-12-12

- Fix tab completion instruction for fish. `#29 <https://github.com/dajiaji/mkkey/pull/29>`__

Version 0.6.0
-------------

Released 2021-12-07

- Add support for PASERK key wrapping with symmetric key. `#25 <https://github.com/dajiaji/mkkey/pull/25>`__

Version 0.5.0
-------------

Released 2021-12-06

- Add support for PASERK password-based key wrapping. `#22 <https://github.com/dajiaji/mkkey/pull/22>`__

Version 0.4.0
-------------

Released 2021-12-05

- Add __main__.py. `#21 <https://github.com/dajiaji/mkkey/pull/21>`__
- Use DER format for "sha256" kid generation method. `#19 <https://github.com/dajiaji/mkkey/pull/19>`__

Version 0.3.0
-------------

Released 2021-12-05

- Add test with external jose library. `#16 <https://github.com/dajiaji/mkkey/pull/16>`__
- Add support for key_ops. `#15 <https://github.com/dajiaji/mkkey/pull/15>`__

Version 0.2.0
-------------

Released 2021-12-04

- Rename option from underscore to hyphen. `#13 <https://github.com/dajiaji/mkkey/pull/13>`__
- Reorder output of paserk. `#12 <https://github.com/dajiaji/mkkey/pull/12>`__
- Refine README and help message. `#9 <https://github.com/dajiaji/mkkey/pull/9>`__

Version 0.1.0
-------------

Released 2021-12-03

- First public release.
